# cyclicTemperatureFoam - An OpenFOAM solver for cyclic heat transfer

## What is cyclicTemperatureFoam?

cyclicTemperatureFoam is a OpenFOAM solver made to solve for cyclic heat transfer. Following the idea presented by Patankar et al. (1977) in:

        Patankar S.V., Liu C.H., Sparrow E.M., 1977. Fully Developed Flow and Heat Transfer in Ducts Having Streamwise-Periodic Variations of Cross-Sectional Area. J. Heat Transfer 99(2), 180-186. doi: 10.1115/1.3450666

the temperature field is split up in a periodic part and a non-periodic part. cyclicTemperatureFoam solves for the periodic temperature field, calculates the wall temperature gradient, bulk temperature and outputs the Nusselt number as: Nu = dTdn*Lc/(Twall-Tbulk), where dTdn is the average surface normal temperature gradient, Lc is a characteristic length and Twall-Tbulk is the temeperature difference. Lc and Twall are user-specified in constant/transportProperties.

## Compatibility

The cyclicTemperatureFoam solver is maintained for the latest OpenFOAM releases. The code was tested on OpenFOAM-5.x and 5.0.

## How to use?

0.  Source your OpenFOAM environment, e.g.: 

        source /home/$USER/OpenFOAM/OpenFOAM-5.x/etc/bashrc

1.  In a linux terminal download the solver with git by typing:

        git clone https://github.com/jakobhaervig/cyclicTemperatureFoam.git
        
2.  Execute the wmake script by typing (will finish in less than 1 minute):

        cd cyclicTemperatureFoam
        wmake

## Assumptions

Incompressible flow and constant thermodynamic and transport properties. That is, heat capacity, thermal conductivity, viscosity, and density cannot be functions of temperature and pressure. This is typically a fine assumption when considering a small periodic section of a geometry.

## How to cite?

If you found this code useful, please cite this code as:

        Hærvig, J., 2018. cyclicTemperatureFoam - An OpenFOAM solver for cyclic heat transfer. GitHub repository. doi: ?
